@@ -1,6 +1,7 @@
 import sys
 import time
 import json
+import hashlib
 
 from pyhmy import cli
 from pyhmy import (
@@ -31,7 +32,8 @@ from .util import (
     input_with_print
 )
 
-tmux_session_name = f"AutoNode-{hash(str(validator_config))}"
+_config_hash = hashlib.sha224(str(validator_config).encode()).hexdigest()
+tmux_session_name = f"AutoNode-{_config_hash[:16]}"
 log_path = f"{harmony_dir}/autonode_validator.log"
 
 
@@ -108,7 +110,7 @@ def _create_new_validator():
     else:
         print(f"{Typgpy.OKGREEN}Address: {validator_config['validator-addr']} has enough funds{Typgpy.ENDC}")
     _verify_node_sync()
-    print(f"\n{Typgpy.OKBLUE}Sending create validator transaction...{Typgpy.ENDC}")
+    print(f"{Typgpy.OKBLUE}Sending create validator transaction...{Typgpy.ENDC}")
     _send_create_validator_tx()
 
 
@@ -154,7 +156,7 @@ def _setup(recover_interaction):
         node_config['no-validator'] = True
 
 
-def setup(recover_interaction=False, error_sleep=15):
+def setup(recover_interaction=False, end_sleep=10):
     if node_config['no-validator']:
         print(f"{Typgpy.WARNING}Node config specifies not validator automation, exiting...{Typgpy.ENDC}")
         return
@@ -164,7 +166,8 @@ def setup(recover_interaction=False, error_sleep=15):
     print(f"{Typgpy.OKBLUE}Using BLS key(s): {Typgpy.OKGREEN}{node_config['public-bls-keys']}{Typgpy.ENDC}")
     try:
         _setup(recover_interaction)
+        time.sleep(end_sleep)
     except Exception as e:
-        time.sleep(error_sleep)
+        time.sleep(end_sleep)
         raise e
 
